openDAQ — openDAQ 0.2.0 documentation

# openDAQ

This is the documentation of the openDAQ Python package

Contents:

- openDAQ usage in Python
  - Device connection and port handling
  - ADC reading (Command-Response mode)
  - DAC setting (CR mode)
  - Stream Experiments Creation (Stream Mode)
  - Capture Input
  - Counter Input
  - Encoder Input
  - PWM Output
  - PIO Configuration and control (CR mode)
  - Bit-bang SPI Output
  - Other functions
  - Calibration
- API documentation
  - opendaq.daq module

# Indices and tables

- Index
- Module Index
- Search Page